﻿using DataSharing.RawData;
using DataSharing.Share.Dtos.YiBin.ZzptPlatformsYB;
using DataSharing.Share.Dtos;
using DataSharing.Share.Dtos.ZiGong.TianQue;
using DotNetCore.CAP;
using MapsterMapper;
using MediatR;
using Microsoft.AspNetCore.Mvc;
using XF.Domain.Filters;
using DataSharing.YiBin.ConvergenceMedia;
using XF.Domain.Repository;

namespace DataSharing.Host.Controllers.ZiGong
{
    /// <summary>
    /// 天阙
    /// </summary>
    public class TianQueController : BaseController
    {
        private readonly IMapper _mapper;
        private readonly IMediator _mediator;
        private readonly ICapPublisher _capPublisher;
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly IDsUserTokenInfoService _dsUserTokenInfoService;
        private readonly IRepository<DsReceiveMediaData> _dsReceiveMediaDataRepository;

        public TianQueController(IMapper mapper,
            IMediator mediator,
            ICapPublisher capPublisher,
            IChannelConfigurationManager channelConfigurationManager,
            IDsUserTokenInfoService dsUserTokenInfoService,
            IRepository<DsReceiveMediaData> dsReceiveMediaDataRepository)
        {
            _mapper = mapper;
            _mediator = mediator;
            _capPublisher = capPublisher;
            _channelConfigurationManager = channelConfigurationManager;
            _dsUserTokenInfoService = dsUserTokenInfoService;
            _dsReceiveMediaDataRepository = dsReceiveMediaDataRepository;
        }

        public async Task<OpenResponse> WriteResult([FromBody] OrderResultDto dto)
        {
            //写入原始数据
            DsReceiveMediaData dsReceiveMediaData = new()
            {
                ServiceInterface = "WriteResult",
                PlatformsName = "天阙",
                ExternalId = dto.ReplyCode,
                ReceiveData = System.Text.Json.JsonSerializer.Serialize(dto)
            };
            var id = await _dsReceiveMediaDataRepository.AddAsync(dsReceiveMediaData, HttpContext.RequestAborted);

            var accountDto = await _dsUserTokenInfoService.CheckAccountAsync(dto.VailCode, HttpContext.RequestAborted);
            if (accountDto is null || accountDto.IsCheckAccount == false)
                return OpenResponse.Ok(TianQueResponse<string>.Failed("密钥错误"));

            //验证数据
            string strResult = dto.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return OpenResponse.Ok(TianQueResponse<string>.Failed(strResult));

            if (false == IsDate(dto.ReplyDate))
                return OpenResponse.Ok(TianQueResponse<string>.Failed("办理时间格式错误"));

            //todo
            //处理推送数据导hotline

            if (!string.IsNullOrEmpty(id))
                return OpenResponse.Ok(TianQueResponse<string>.Success("回复提交成功"));
            else
                return OpenResponse.Ok(TianQueResponse<string>.Failed("回复提交失败"));
        }

        private bool IsDate(string strDate)
        {
            try
            {
                DateTime.Parse(strDate);  //不是字符串时会出现异常
                return true;
            }
            catch
            {
                return false;
            }
        }

    }
}
